@@ -27,6 +27,13 @@
 ##' @name show-methods
 ##' @aliases show show-methods show,Contacts-method show,ContactTrace-method
 ##' @docType methods
+##' @keywords methods
+##' @export
+##' @include Contacts.r
+##' @include ContactTrace.r
+##' @param object The \code{\linkS4class{Contacts}} or
+##' \code{\linkS4class{ContactTrace}} \code{object}
+##' @return None (invisible 'NULL').
 ##' @section Methods: \describe{
 ##'
 ##'   \item{\code{signature(object = "Contacts")}}{
@@ -49,9 +56,8 @@
 ##'     disease control and riskbased surveillance.  Preventive Veterinary
 ##'     Medicine 99 (2011) 78-90, doi: 10.1016/j.prevetmed.2010.12.009
 ##' }
-##' @keywords methods
-##' @export
 ##' @examples
+##' \dontrun{
 ##'
 ##' ## Load data
 ##' data(transfers)
@@ -63,65 +69,65 @@
 ##'                       days=90)
 ##'
 ##' show(contactTrace)
-##'
-setMethod('show',
-          signature(object = 'Contacts'),
+##'}
+setMethod("show",
+          signature(object = "Contacts"),
           function (object)
       {
-          arrow <- ifelse(identical(object@direction, 'in'), '<<<', '>>>')
-          prefix <- ifelse(identical(object@direction, 'in'), 'In', 'Out')
+          arrow <- ifelse(identical(object@direction, "in"), "<<<", ">>>")
+          prefix <- ifelse(identical(object@direction, "in"), "In", "Out")
 
-          cat(sprintf('%s %s contacts %s\n', arrow, prefix, arrow))
+          cat(sprintf("%s %s contacts %s\n", arrow, prefix, arrow))
 
-          cat(sprintf('%s begin date: %s\n', prefix, object@tBegin))
-          cat(sprintf('%s end date:   %s\n', prefix, object@tEnd))
-          cat(sprintf('%s days: %i\n', prefix, object@tEnd - object@tBegin))
+          cat(sprintf("%s begin date: %s\n", prefix, object@tBegin))
+          cat(sprintf("%s end date:   %s\n", prefix, object@tEnd))
+          cat(sprintf("%s days: %i\n", prefix, object@tEnd - object@tBegin))
 
-          if(identical(object@direction, 'out')) {
-              cat(sprintf('%s degree: %s\n', prefix, OutDegree(object)))
-              cat(sprintf('%sgoing contact chain: %i\n\n', prefix, OutgoingContactChain(object)))
+          if(identical(object@direction, "out")) {
+              cat(sprintf("%s degree: %s\n", prefix, OutDegree(object)))
+              cat(sprintf("%sgoing contact chain: %i\n\n", prefix, OutgoingContactChain(object)))
           } else {
-              cat(sprintf('%s degree: %s\n', prefix, InDegree(object)))
-              cat(sprintf('%sgoing contact chain: %i\n\n', prefix, IngoingContactChain(object)))
+              cat(sprintf("%s degree: %s\n", prefix, InDegree(object)))
+              cat(sprintf("%sgoing contact chain: %i\n\n", prefix, IngoingContactChain(object)))
           }
 
           if(length(object@source) > 0L) {
-              arrow <- ifelse(identical(object@direction, 'out'), '-->', '<--')
+              arrow <- ifelse(identical(object@direction, "out"), "-->", "<--")
               width <- max(nchar(object@source), nchar(object@destination))
-              format <- sprintf('%%s%% %is %s %% %is\n', width, arrow, width)
+              format <- sprintf("%%s%% %is %s %% %is\n", width, arrow, width)
 
               ## Get network structure. The distance is used for indentation.
               ns <- NetworkStructure(object)
 
               ## Rename source and destination to lhs and rhs, with respect to direction
-              if(identical(object@direction, 'out')) {
-                  names(ns)[names(ns) == 'source'] <- 'lhs'
-                  names(ns)[names(ns) == 'destination'] <- 'rhs'
+              if(identical(object@direction, "out")) {
+                  names(ns)[names(ns) == "source"] <- "lhs"
+                  names(ns)[names(ns) == "destination"] <- "rhs"
               } else {
-                  names(ns)[names(ns) == 'source'] <- 'rhs'
-                  names(ns)[names(ns) == 'destination'] <- 'lhs'
+                  names(ns)[names(ns) == "source"] <- "rhs"
+                  names(ns)[names(ns) == "destination"] <- "lhs"
               }
 
               for(i in seq_len(nrow(ns))) {
                   cat(sprintf(format,
-                              paste(rep(' ', (ns$distance[i] - 1) * (width + 5)), collapse=''),
+                              paste(rep(" ", (ns$distance[i] - 1) * (width + 5)), collapse=""),
                               ns$lhs[i],
                               ns$rhs[i]))
               }
 
           } else {
-              cat(sprintf('No %sgoing contacts during the search period.\n', object@direction))
+              cat(sprintf("No %sgoing contacts during the search period.\n", object@direction))
           }
 
-          cat('\n')
+          cat("\n")
       }
 )
 
-setMethod('show',
-          signature(object = 'ContactTrace'),
+setMethod("show",
+          signature(object = "ContactTrace"),
           function (object)
       {
-          cat(sprintf('Root: %s\n\n', object@root))
+          cat(sprintf("Root: %s\n\n", object@root))
           show(object@ingoingContacts)
           show(object@outgoingContacts)
       }
